NAME
Sys::OsRelease::Lite - repackaged distribution to provide Sys::OsRelease on Perl older than 5.22
SYNOPSIS
none
DESCRIPTION
Sys::OsRelease::Lite serves only as an installation target for an alternative way to install Sys::OsRelease on Perl versions older than 5.22. It provides no other functionality except to make Sys::OsRelease available as part of the distribution.
This is a repackaging of Sys::OsRelease for older versions of Perl before 5.22. This was made because dependencies of Dist::Zilla forced it to bump its minimum Perl version to 5.22, which in turn forced Sys::OsRelease to follow. Sys::OsRelease::Lite provides Sys::OsRelease with the same source code, implemented as a symbolic link in the common Git repository that houses both modules. It is packaged with ExtUtils::MakeMaker to maintain availability back to Perl 5.10. Compatibility was at time time still being maintained via CPAN testing was back to 5.10. The use case was systems with RHEL 6 on Perl 5.10.1 and RHEL 7 on Perl 5.16, or similar variations.
SEE ALSO
FreeDesktop.Org's os-release standard: https://www.freedesktop.org/software/systemd/man/os-release.html
GitHub repository for Sys::OsRelease: https://github.com/ikluft/Sys-OsRelease
BUGS AND LIMITATIONS
Please report bugs via GitHub at https://github.com/ikluft/Sys-OsRelease/issues
Patches and enhancements may be submitted via a pull request at https://github.com/ikluft/Sys-OsRelease/pulls
LICENSE INFORMATION
This module is distributed in the hope that it will be useful, but it is provided “as is” and without any express or implied warranties. For details, see the full text of the license in the file LICENSE or at https://www.perlfoundation.org/artistic-license-20.html.
AUTHOR
Ian Kluft <https://github.com/ikluft>
COPYRIGHT AND LICENSE
This software is Copyright (c) 2022-2026 by Ian Kluft.
This is free software, licensed under:
The Artistic License 2.0 (GPL Compatible)